Author: rinrab
Date: Mon Jun 9 12:29:55 2025
New Revision: 1926280
URL: http://svn.apache.org/viewvc?rev=1926280&view=rev
Log:
On the 'utf8-cmdline-prototype' branch: Following up to r1925828: rename
the utf8_opt_arg argument to opt_arg in parse_compatible_version().
* subversion/svn/svn.c
(parse_compatible_version): Ditto.
Modified:
subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c
Modified: subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c?rev=1926280&r1=1926279&r2=1926280&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c Mon Jun 9 12:29:55 2025
@@ -2130,7 +2130,7 @@ add_commands(const svn_opt_subcommand_de
svn_cl__cmd_table = cmds_new;
}
/* Parse UTF8_OPT_ARG as a version number, into OPT_STATE->compatible_version.
*
* Ensure it is between the oldest and newest supported WC formats.
*
@@ -2140,7 +2140,7 @@ add_commands(const svn_opt_subcommand_de
*/
static svn_error_t *
parse_compatible_version(svn_cl__opt_state_t* opt_state,
- const char *utf8_opt_arg,
+ const char *opt_arg,
apr_pool_t *result_pool)
{
svn_version_t *target;
@@ -2155,7 +2155,7 @@ parse_compatible_version(svn_cl__opt_sta
oldest->major, oldest->minor, 0));
/* Parse the requested version. */
- SVN_ERR(svn_version__parse_version_string(&target, utf8_opt_arg,
+ SVN_ERR(svn_version__parse_version_string(&target, opt_arg,
result_pool));
/* Quietly ignore 'patch' and 'tag' fields. */
target->patch = 0;
@@ -2130,7 +2130,7 @@ add_commands(const svn_opt_subcommand_de
svn_cl__cmd_table = cmds_new;
}
-/* Parse UTF8_OPT_ARG as a version number, into OPT_STATE->compatible_version.
+/* Parse OPT_ARG as a version number, into OPT_STATE->compatible_version.
*
* Ensure it is between the oldest and newest supported WC formats.
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.